default_materials = {
    "metric": {
        "Structural Steel": {
            "name": "Structural Steel",
            "density": 7850,
            "elasticity_modulus": 200000,
            "poissons_ratio": 0.27,
            "yield_strength": 260,
            "ultimate_strength": 410,
            "class": "steel"
        },
        "Aluminium": {
            "name": "Aluminium",
            "density": 2700,
            "elasticity_modulus": 69000,
            "poissons_ratio": 0.32,
            "yield_strength": 100,
            "ultimate_strength": 150,
            "class": "aluminium"
        },
        "Carbon Fibre Reinforced Plastic": {
            "name": "Carbon Fibre Reinforced Plastic",
            "density": 3500,
            "elasticity_modulus": 150000,
            "poissons_ratio": 0.2,
            "yield_strength": None,
            "ultimate_strength": 2705,
            "class": "other"
        },
        "Concrete": {
            "name": "Concrete",
            "density": 2500,
            "elasticity_modulus": 17000,
            "poissons_ratio": 0.2,
            "yield_strength": None,
            "ultimate_strength": 3.5,
            "class": "concrete"
        },
        "Concrete High Strength": {
            "name": "Concrete High Strength",
            "density": 2500,
            "elasticity_modulus": 30000,
            "poissons_ratio": 0.2,
            "yield_strength": None,
            "ultimate_strength": 5,
            "class": "concrete"
        },
        "Oakwood": {
            "name": "Oakwood",
            "density": 900,
            "elasticity_modulus": 11000,
            "poissons_ratio": 0.3,
            "yield_strength": 4.5,
            "ultimate_strength": 5,
            "class": "wood"
        },
        "Glass": {
            "name": "Glass",
            "density": 2500,
            "elasticity_modulus": 70000,
            "poissons_ratio": 0.24,
            "yield_strength": None,
            "ultimate_strength": 33,
            "class": "other"
        }
    },
    "imperial": {
        "Structural Steel": {
            "name": "Structural Steel",
            "density": 490,
            "elasticity_modulus": 29000,
            "poissons_ratio": 0.27,
            "yield_strength": 36,
            "ultimate_strength": 58,
            "class": "steel"
        },
        "Aluminium": {
            "name": "Aluminium",
            "density": 167,
            "elasticity_modulus": 10000,
            "poissons_ratio": 0.32,
            "yield_strength": 15,
            "ultimate_strength": 22,
            "class": "aluminium"
        },
        "Carbon Fibre Reinforced Plastic": {
            "name": "Carbon Fibre Reinforced Plastic",
            "density": 200,
            "elasticity_modulus": 21800,
            "poissons_ratio": 0.2,
            "yield_strength": "",
            "ultimate_strength": 460,
            "class": "other"
        },
        "Concrete": {
            "name": "Concrete",
            "density": 150,
            "elasticity_modulus": 2500,
            "poissons_ratio": 0.2,
            "yield_strength": "",
            "ultimate_strength": 0.5,
            "class": "concrete"
        },
        "Concrete High Strength": {
            "name": "Concrete High Strength",
            "density": 150,
            "elasticity_modulus": 4400,
            "poissons_ratio": 0.2,
            "yield_strength": "",
            "ultimate_strength": 0.75,
            "class": "concrete"
        },
        "Oakwood": {
            "name": "Oakwood",
            "density": 56,
            "elasticity_modulus": 1600,
            "poissons_ratio": 0.3,
            "yield_strength": 0.65,
            "ultimate_strength": 0.75,
            "class": "wood"
        },
        "Glass": {
            "id": 7,
            "name": "Glass",
            "density": 160,
            "elasticity_modulus": 10000,
            "poissons_ratio": 0.24,
            "yield_strength": "",
            "ultimate_strength": 4.8,
            "class": "other"
        }
    }
}
